@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 from string import Template
-import re
 
 
 class PyTemplate(Template):
@@ -8,9 +7,9 @@ class PyTemplate(Template):
     Template strings that can replace ##{PATTERN} instances.
     """
     def __init__(self, t):
-        super(PyTemplate, self).__init__(t.replace('$', '$$').replace('##{', '${'))
+        super(PyTemplate, self).__init__(t.replace(b'$', b'$$').replace(b'##{', b'${'))
 
     def substitute(self, *args, **kw):
         return super(PyTemplate, self).substitute(
-            **{k.upper(): v for k, v in kw.iteritems()}
+            **{k.upper(): v for k, v in kw.items()}
         )
